import request from '@/utils/request'

// 查询仓库
export function initWarehouse() {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_货位仓库_仓库_查询数据'
    }
  })
}
// 增加仓库
export function addWarehouse(num0, num1, num2, num3, num4, num5) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_货位仓库_仓库_增加数据',
      param: '仓库编号=' + num0 + '&仓库名称=' + num1 + '&仓库描述=' + num2 + '&地址=' + num3 + '&联系人=' + num4 + '&备注=' + num5
    }
  })
}
// 修改仓库
export function alterWarehouse(num, num0, num1, num2, num3, num4, num5) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_货位仓库_仓库_修改数据',
      param: '仓库流水号=' + num + '&仓库编号=' + num0 + '&仓库名称=' + num1 + '&仓库描述=' + num2 + '&地址=' + num3 + '&联系人=' + num4 + '&备注=' + num5
    }
  })
}
// 删除仓库
export function deleteWarehouse(num) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_货位仓库_仓库_删除数据',
      param: '仓库流水号=' + num
    }
  })
}
// 查询货位
export function searchLocate(num) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_货位主文件_查询数据',
      param: '仓库流水号=' + num
    }
  })
}
// 增加货位
export function addLocate(num0, num1, num2, num3, num4) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_货位主文件_增加数据',
      param: '货位名称=' + num0 + '&工作中心=' + num1 + '&仓库流水号=' + num2 + '&永久=' + num3 + '&不可用量=' + num4
    }
  })
}
// 修改货位
export function alterLocate(num, num0, num1, num2, num3, num4) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_货位主文件_修改数据',
      param: '货位流水号=' + num + '&货位名称=' + num0 + '&工作中心=' + num1 + '&仓库流水号=' + num2 + '&永久=' + num3 + '&不可用量=' + num4
    }
  })
}
// 删除货位
export function deleteLocate(num) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_货位主文件_删除数据',
      param: '货位流水号=' + num
    }
  })
}
// 人员查询 需要在部门确定之后修改
export function searchPeople(role) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '菜单系统模块_项目角色员工综合_查询数据',
      param: '姓名_check=' + 0 + '&角色编号_check=' + 1 + '&角色编号=' + role + '&考核部门编号_check=' + 0
    }
  })
}
